@@ -14,6 +14,8 @@ ErrorMap = Iterable[Tuple[Exception, str, int]]
 class ErrorHandler:
     """Handles common errors and exits."""
 
+    __slots__ = ('errors', 'logger')
+
     def __init__(self, errors: ErrorMap, logger: Logger):
         """Sets the logger."""
         self.errors = errors
@@ -22,9 +24,9 @@ class ErrorHandler:
     def __enter__(self):
         return self
 
-    def __exit__(self, typ, *_):
+    def __exit__(self, typ, value, _):
         """Checks for connection errors and exits respectively."""
-        for error, (message, returncode) in self.errors.items():
-            if isinstance(typ, error):
+        for exception, message, returncode in self.errors:
+            if typ is exception or isinstance(value, exception):
                 self.logger.error(message)
                 exit(returncode)
