@@ -20,9 +20,9 @@ __all__ = ['get_credentials', 'main']
 
 ERRORS = (
     (ConnectionRefusedError, 'Connection refused.', 3),
-    (timeout, 'Connection timeout.', 4),
+    ((TimeoutError, timeout), 'Connection timeout.', 4),
     (RequestIdMismatch, 'Unexpected request ID mismatch.', 5),
-    (WrongPassword, 'Wrong password.', 6),
+    (WrongPassword, 'Wrong password.', 6)
 )
 LOGGER = getLogger('rconclt')
 
@@ -66,6 +66,7 @@ def get_credentials(args: Namespace) -> Tuple[str, int, str]:
 
     return (host, port, passwd)
 
+
 def main():
     """Runs the RCON client."""
 
