@@ -7,16 +7,19 @@ from socket import timeout
 from sys import exit    # pylint: disable=W0622
 
 from rcon.errorhandler import ErrorHandler
+from rcon.exceptions import RequestIdMismatch
 from rcon.rconclt import get_credentials
+from rcon.readline import CommandHistory
 from rcon.config import CONFIG_FILE, LOG_FORMAT
-from rcon.console import rconcmd
+from rcon.console import PROMPT, rconcmd
 
 
 __all__ = ['get_args', 'main']
 
 ERRORS = (
     (ConnectionRefusedError, 'Connection refused.', 3),
-    (timeout, 'Connection timeout.', 4)
+    ((TimeoutError, timeout), 'Connection timeout.', 4),
+    (RequestIdMismatch, 'Unexpected request ID mismatch.', 5)
 )
 LOGGER = getLogger('rconshell')
 
@@ -28,12 +31,12 @@ def get_args() -> Namespace:
     parser.add_argument('server', nargs='?', help='the server to connect to')
     parser.add_argument('-c', '--config', type=Path, metavar='file',
                         default=CONFIG_FILE, help='the configuration file')
-    parser.add_argument('-p', '--prompt', default='RCON> ', metavar='PS1',
+    parser.add_argument('-p', '--prompt', default=PROMPT, metavar='PS1',
                         help='the shell prompt')
     return parser.parse_args()
 
 
-def main():
+def run() -> int:
     """Runs the RCON shell."""
 
     args = get_args()
@@ -45,6 +48,13 @@ def main():
         host = port = passwd = None
 
     with ErrorHandler(ERRORS, LOGGER):
-        exit_code = rconcmd(host, port, passwd, args.prompt)
+        return rconcmd(host, port, passwd, prompt=args.prompt)
 
-    exit(exit_code)
+
+def main():
+    """Wraps the run function."""
+
+    with CommandHistory():
+        returncode = run()
+
+    exit(returncode)
